Method: CF::Badge.list

Defined in:
lib/cf/badge.rb

.list(name = nil) ⇒ Object

list all badges with in the account if name is not provided else it will return list all values of the given badge



111
112
113
114
115
# File 'lib/cf/badge.rb', line 111

def self.list(name = nil)
  response =  get("/accounts/#{CF.account_name}/badges.json", :name => name)
  @errors = response['error']['message'] if response['code'] != 200
  return response
end